@@ -12,4 +12,9 @@
   subtext <- tklabel(startup,text= "TTAinterface v1.01 launch panel")                       
   tkconfigure(subtext, font=tkfont.create(size=7))                                              
   tkgrid(subtext, column=1, row=4)
+   
 }
+
+if(getRversion() >= "2.15.1") globalVariables(names=c("STATIONS","S","DEPTH","MONTHS", "param",
+"depth","sal","site","npsu"), 
+package="TTAinterfaceTrendAnalysis")
\ No newline at end of file
